Contributing
============

General notes
-------------

See `contributing from transistordatabase
project <https://github.com/upb-lea/transistordatabase/blob/main/Contributing.rst>`__

Additional things for FEMMT project
-----------------------------------

json config files
~~~~~~~~~~~~~~~~~

The user should not interact with these files! Store data which might be
good for user usability: \* onelab path \* working-directory variable
(mesh data, …) \* log-data

Folder structure
~~~~~~~~~~~~~~~~

Folder ‘examples’: All kind of examples -> examples/dual_active_bridge/
-> examples/basic_example.py

Folder femm All kind of femm-interactions -> femm/thermal_validation ->
femm/coil_validation

Folder results -> results/magnetics/ -> results/thermal/
